@@ -8,7 +8,7 @@ import socket
 from flask import Flask, Response
 from flask import request, current_app, stream_with_context
 
-DEBUG = True
+DEBUG = False
 TERMINATOR = '\n'
 
 GOURD_HTTP_DEFAULT_HOST = '127.0.0.1'
@@ -81,6 +81,7 @@ def build_parser():
     parser.add_argument('-p', '--port', default=app.config['GOURD_HTTP_DEFAULT_PORT'], type=int, help='bind port', action='store')
     parser.add_argument('-a', '--ghost', default=app.config['GOURD_SERVER_HOST'], help='gourd host', action='store')
     parser.add_argument('-b', '--gport', default=app.config['GOURD_SERVER_PORT'], type=int, help='gourd port', action='store')
+    parser.add_argument('-d', '--debug', default=False, help='debug mode', action='store_true')
     return parser
 
 
@@ -90,10 +91,13 @@ def main():
     from gevent import wsgi
 
     args = build_parser().parse_args()
+    app.debug = args.debug
     app.config['GOURD_SERVER_HOST'] = args.ghost
     app.config['GOURD_SERVER_PORT'] = args.gport
 
-    print "* Running gourd_http on http://%s:%s, gourd is %s:%s" % (args.host, args.port, args.ghost, args.gport)
+    app.logger.info("* Running gourd_http on http://%s:%s, gourd is %s:%s, debug:%s" % (
+        args.host, args.port, args.ghost, args.gport, args.debug
+    ))
     wsgi.WSGIServer((args.host, int(args.port)), app).serve_forever()
 
 
