@@ -305,8 +305,9 @@ class UdpServer(asyncore.dispatcher, CallBackMgr):
 
     @catch_exc
     def handle_read(self):
-        self._raw_data, self._address = self.socket.recvfrom(constants.PACKAGE_SIZE)
-        handle_input_data(self)
+        raw_data, address = self.socket.recvfrom(constants.PACKAGE_SIZE)
+        request = UdpRequestHandler(self, address, raw_data)
+        request.process()
 
     def run(self, host, port):
         self.create_socket(socket.AF_INET, socket.SOCK_DGRAM)
@@ -314,6 +315,28 @@ class UdpServer(asyncore.dispatcher, CallBackMgr):
 
         asyncore.loop(map=self._map)
 
+    def make_rsp(self, **kwargs):
+        """
+        生成rsp
+        """
+        return json.dumps(kwargs)
+
+
+class UdpRequestHandler(object):
+    _server = None
+    _address = None
+    _raw_data = None
+    _json_data = None
+
+    def __init__(self, server, address, raw_data):
+        super(UdpRequestHandler, self).__init__()
+        self._server = server
+        self._address = address
+        self._raw_data = raw_data
+
+    def process(self):
+        handle_input_data(self)
+
     def push(self, data):
         """
         发送数据，为了tcp一致
@@ -325,18 +348,21 @@ class UdpServer(asyncore.dispatcher, CallBackMgr):
         except Exception, e:
             self.server.logger.error('exception occur. e: %s, tbk: %s', e, __import__('traceback').format_exc())
 
-    def make_rsp(self, **kwargs):
-        """
-        生成rsp
-        """
-        return json.dumps(kwargs)
+    def close(self):
+        # 只是为了保持接口一致而已
+        pass
+
+    @property
+    def socket(self):
+        # 这个也是为了解决接口兼容而已，外界不要动他比较好
+        return self.server.socket
 
     @property
     def server(self):
         """
         获取当前server
         """
-        return self
+        return self._server
 
     @property
     def address(self):
@@ -352,4 +378,3 @@ class UdpServer(asyncore.dispatcher, CallBackMgr):
         获取获取的json数据
         """
         return self._json_data
-
